Stan Math Library: stan/math/prim/arr/meta/index_type.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

index_type.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_ARR_META_INDEX_TYPE_HPP
2 #define STAN_MATH_PRIM_ARR_META_INDEX_TYPE_HPP
3
4 #include <stan/math/prim/scal/meta/index_type.hpp>
5 #include <vector>
6
7 namespace stan {
8
9 namespace math {
10
17 template <typename T>
18 struct index_type<std::vector<T> > {
22 typedef typename std::vector<T>::size_type type;
23 };
24
25
26 }
27 }
28
29
30 #endif
index_type.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::index_type< std::vector< T > >::type
std::vector< T >::size_type type
Typedef for index of standard vectors.
Definition: index_type.hpp:22
std
Definition: std_numeric_limits.hpp:7
stan::math::size_type
Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic >::Index size_type
Type for sizes and indexes in an Eigen matrix with double e.
Definition: typedefs.hpp:13
stan::math::index_type
Primary template class for the metaprogram to compute the index type of a container.
Definition: index_type.hpp:19

[ Stan Home Page ] © 2011–2016, Stan Development Team.